@@ -1,14 +1,18 @@
 # -*- coding: utf-8 -*-
-
 """
 Pywinpty
 ========
 This package provides a Cython wrapper around winpty C++ library.
 """
-try:
-    from .winpty_wrapper import PTY
-except ImportError:
-    pass
 
-VERSION_INFO = (0, 1, 0, 'post1')
+# yapf: disable
+
+# Local imports
+from .winpty_wrapper import PTY
+
+
+# yapf: enable
+
+PTY
+VERSION_INFO = (0, 1, 2)
 __version__ = '.'.join(map(str, VERSION_INFO))
